using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace DialogBoxesDemo
{
    public partial class Form1 : Form
    {

        private OptionsForm options = null;
        private SpellCheckForm speller = null;

        public Form1()
        {
            InitializeComponent();
        }

        private void changeOptionsButton_Click(object sender, EventArgs e)
        {
            if (options == null)
            {
                options = new OptionsForm();
            }

            // Show modal dialog and wait until dialog box is dismissed
            if (options.ShowDialog() == DialogResult.OK)
            {
                if (options.SoundOn)
                    label1.Text = "Sound is on.";
                else
                    label1.Text = "Sound is off.";
            }
        }

        private void spellCheckButton_Click(object sender, EventArgs e)
        {
            if (speller == null || speller.IsDisposed)
            {
                speller = new SpellCheckForm();

                // Call this function when FormClosed event is received
                speller.FormClosed += SpellCheckForm_FormClosed;

                // Lister for the custom event which tells us when Replace button is clicked
                speller.Change += SpellCheckForm_Change;
            }

            speller.Show(this);
            spellCheckButton.Enabled = false;  // So user can't click on it

        }

        private void SpellCheckForm_Change(object sender, EventArgs e)
        {
            wordLabel.Text = speller.Word;
        }

        private void SpellCheckForm_FormClosed(object sender, EventArgs e)
        {
            // Re-enable the button when the dialog box is closed
            spellCheckButton.Enabled = true;
        }

        private void openFileButton_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                MessageBox.Show("File selected: " + openFileDialog1.FileName);
            }
        }

        private void colorDialogButton_Click(object sender, EventArgs e)
        {
            if (colorDialog1.ShowDialog() == DialogResult.OK)
            {
                MessageBox.Show("Color: " + colorDialog1.Color);
            }
        }

        private void fontChangeButton_Click(object sender, EventArgs e)
        {
            if (fontDialog1.ShowDialog() == DialogResult.OK)
            {
                MessageBox.Show("Font: " + fontDialog1.Font);
            }
        }

        private void browseFolderButton_Click(object sender, EventArgs e)
        {
            if (folderBrowserDialog1.ShowDialog() == DialogResult.OK)
            {
                MessageBox.Show("Path: " + folderBrowserDialog1.SelectedPath);
            }
        }

        private void saveFileButton_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                MessageBox.Show("File: " + saveFileDialog1.FileName);
            }
        }

    }
}